#!/bin/bash
# MODEM-TOOL - Easy dialog-based configuration of Modems
# Luckily, we can (almost) skip the hardware-dependent stuff
# (C) Klaus Knopper Aug 2004

PATH="/bin:/sbin:/usr/bin:/usr/sbin:/usr/X11R6/bin:/usr/local/bin"
export PATH

# Get root
[ "`id -u`" != "0" ] && exec sudo "$0" "$@"
unset SUDO_COMMAND

XDIALOG_HIGH_DIALOG_COMPAT=1
export XDIALOG_HIGH_DIALOG_COMPAT

XDIALOG_FORCE_AUTOSIZE=1
export XDIALOG_FORCE_AUTOSIZE

TMP="/tmp/modemtool.$$"

bailout(){
rm -f "$TMP"
exit $1
}

DIALOG="dialog"
[ -n "$DISPLAY" ] && [ -x /usr/bin/Xdialog ] && DIALOG="Xdialog"

trap bailout 1 2 3 15

BACKTITLE="KNOPPIX MODEM-TOOL"

[ -f /etc/sysconfig/knoppix ] && . /etc/sysconfig/knoppix
[ -z "$LANG" ] && export LANG
[ -z "$LANGUAGE" ] && export LANGUAGE
[ -z "$CHARSET" ] && export CHARSET

# Language-dependent Messages
case "$LANGUAGE" in
de*|at*|ch*)
EXIT="Beenden"
DIAL="Verbindung aufbauen"
CURRENTPROVIDER="Keiner ausgewhlt"
SETTINGS="Modem-Einstellungen"
MAIN="Hauptmen"
PPHONE="Provider Telefonnummer"
ENTER_PPHONE="Bitte geben Sie die VOLLSTNDIGE Telefonnummer Ihres Internet-Anbieters ein. Falls Sie sich in einem Hotel befinden, mssen Sie ggf. \"0,\" als Prefix angeben, um die Amtsleitung freizuschalten."
PLOGIN="Provider Login"
PPASSWORD="Provider Passwort"
HARDWARE="Modem-Einstellungen"
EDIT="Anschauen/Bearbeiten"
PROVIDER="Provider"
HARDWARE="Hardware"
TITLE_GAUGE="Arbeite..."
INVISIBLE="unsichtbar"
DIALHELP="Alle fr eine Modem-Verbindung notwendigen Einstellungen sind nun gesetzt. Whlen Sie \"Verbindung aufbauen\" im Hauptmen, um eine Verbindung zum Provider herzustellen."
CONFIGHELP="Sie haben noch nicht alle notwendigen Einstellungen fr eine Modem-Verbindung gesetzt. Wahrscheinlich werden Sie so keine Verbindung aufbauen knnen."
CANCELHELP="WVDIAL (Steuerung-C zum Beenden)"
END="Verbindung beendet. Bitte Eingabetaste drcken, um zum Men zurckzukehren."
SAVE="nderungen speichern und aktivieren"
BACK="Zurck"
;;
*)
EXIT="Quit"
DIAL="Connect"
CURRENTPROVIDER="None"
SETTINGS="Modem Settings"
MAIN="Main Menu"
PPHONE="Provider phone number"
ENTER_PPHONE="Please enter the FULL PHONE NUMBER of your internet provider. If you reside in a hotel, you may have to add \"0,\" as prefix in order to reach an outside line."
PLOGIN="Provider Login"
PPASSWORD="Provider Password"
EDIT="View/Edit"
PROVIDER="Provider"
HARDWARE="Modem Setup"
TITLE_GAUGE="Working..."
INVISIBLE="not shown"
DIALHELP="All settings necessary for creating a modem connection have been made. Please select \"Connect\" in the main menu in order to create a modem connection to your provider."
CONFIGHELP="You have not set all options necessary for creating a modem connection yet. You will probably not be able to connect to your provider this way."
CANCELHELP="WVDIAL (Control-C to quit)"
END="Connection terminated. Please hit ENTER to return to the menu."
SAVE="Save/Activate Changes"
BACK="Return"
;;
esac

# Default Settings
PROVIDER_PHONE=""
PROVIDER_LOGIN=""
PROVIDER_PASSWORD=""

# Read in previously saved values
[ -f /etc/sysconfig/modem ] && . /etc/sysconfig/modem

gauge(){
rm -f "$TMP.done"
status=0
while [ ! -e "$TMP.done" ]; do echo "$status" ; status="`expr \( 100 - $status \) / 4 + $status`"; sleep 2; done | $DIALOG --title "$TITLE_GAUGE" --gauge "$1" 8 75 0
}

# Stop status bar
killgauge(){
touch "$TMP.done" ; wait ; rm -f "$TMP.done"
}

# writeconfig variable_name variable_content
writeconfig(){
rm -f "$TMP"
egrep -v "(^$1)" /etc/sysconfig/modem >"$TMP" 2>/dev/null
echo "$1=\"$2\"" >> "$TMP"
cat "$TMP" > /etc/sysconfig/modem
rm -f "$TMP"
}
 
provider(){
while true; do
SETTINGS_MENU=("$PPHONE" "$PROVIDER_PHONE" \
"$PLOGIN" "$PROVIDER_LOGIN" \
"$PPASSWORD" "*** $INVISIBLE ***" \
"$SAVE" "")
rm -f "$TMP"
$DIALOG --cancel-label "$BACK" --backtitle "$BACKTITLE" --title "$SETTINGS" --menu "" 15 75 8 "${SETTINGS_MENU[@]}" 2>"$TMP" || break
case "$(<$TMP)" in
$PPHONE) pphone;;
$PLOGIN) plogin;;
$PPASSWORD) ppassword;;
$SAVE) savesettings; break;;
esac
done
rm -f "$TMP"
if [ "$PROVIDER_PHONE" -a -n "$PROVIDER_LOGIN" -a -n "$PROVIDER_PASSWORD" ]; then
$DIALOG --backtitle "$BACKTITLE" --title "$SETTINGS" --msgbox "$DIALHELP" 12 65
return 0
else
$DIALOG --backtitle "$BACKTITLE" --title "$SETTINGS" --msgbox "$CONFIGHELP" 11 65
return 1
fi
}

settings(){
modemlink
}

pphone(){
rm -f "$TMP"
$DIALOG --backtitle "$BACKTITLE" --title "$PPHONE" --inputbox "$ENTER_PPHONE" 12 55 "$PROVIDER_PHONE" 2>"$TMP" || { rm -f "$TMP"; return 0; }
perl -pi -e "s/[^0-9]//g" "$TMP"
PROVIDER_PHONE="$(<$TMP)"
rm -f "$TMP"
}

plogin(){
rm -f "$TMP"
$DIALOG --backtitle "$BACKTITLE" --title "$PLOGIN" --inputbox "" 8 55 "$PROVIDER_LOGIN" 2>"$TMP" || { rm -f "$TMP"; return 0; }
PROVIDER_LOGIN="$(<$TMP)"
rm -f "$TMP"
}

ppassword(){
rm -f "$TMP"
if [ "$DIALOG" = "Xdialog" ]; then
$DIALOG --password --backtitle "$BACKTITLE" --title "$PPASSWORD" --inputbox "" 8 55 "$PROVIDER_PASSWORD" 2>"$TMP" || { rm -f "$TMP"; return 0; }
else
$DIALOG --insecure --backtitle "$BACKTITLE" --title "$PPASSWORD" --passwordbox "" 8 55 "$PROVIDER_PASSWORD" 2>"$TMP" || { rm -f "$TMP"; return 0; }
fi
PROVIDER_PASSWORD="$(<$TMP)"
rm -f "$TMP"
}

savesettings(){
writeconfig PROVIDER_PHONE "$PROVIDER_PHONE"
writeconfig PROVIDER_LOGIN "$PROVIDER_LOGIN"
writeconfig PROVIDER_PASSWORD "$PROVIDER_PASSWORD"
perl -pi -e "s/^Phone.*=.*/Phone = $PROVIDER_PHONE/g;s/^Username.*=.*/Username = \"$PROVIDER_LOGIN\"/g;s/^Password.*=.*/Password = \"$PROVIDER_PASSWORD\"/g" /etc/wvdial.conf
}

dial(){
if [ -n "$DISPLAY" ]; then
xterm -T "$CANCELHELP" -e wvdial; RC="$?"
else
echo "[1m$CANCELHELP[0m"
trap "" 2
wvdial;  RC="$?"
read -p "$END " relax
trap bailout 2
fi
return $RC
}

main(){
[ -f /etc/sysconfig/modem ] && . /etc/sysconfig/modem
rm -f "$TMP"
$DIALOG --cancel-label "$EXIT" --backtitle "$BACKTITLE" --title "$MAIN" --menu "" 12 75 5 "${DIAL}" "" "${PROVIDER}" "${PROVIDER_PHONE}" "${SETTINGS}" "$EDIT" 2>"$TMP"
[ "$?" != "0" ] && return 1
read SELECTION <"$TMP"
rm -f "$TMP"
case "$SELECTION" in
 $DIAL*)   dial;;
 $SETTINGS*) settings;;
 $PROVIDER*) provider;;
 *)          return 5;;
esac
return 0
}

# MAIN
while true; do main || break; done
bailout 0
